Learn R Programming

R4GoodPersonalFinances (version 1.2.0)

calc_purchasing_power: Calculate purchasing power

Description

Calculates changes in purchasing power over time, taking into account the real interest rate.

Usage

calc_purchasing_power(x, years, real_interest_rate)

Value

A numeric. The purchasing power.

Arguments

x

A numeric. The initial amount of money.

years

A numeric. The number of years.

real_interest_rate

A numeric. The yearly real interest rate.

Details

The real interest rate is the interest rate after inflation. If negative (e.g. equal to the average yearly inflation rate) it can show diminishing purchasing power over time. If positive, it can show increasing purchasing power over time, and effect of compounding interest on the purchasing power.

See Also

Examples

Run this code
calc_purchasing_power(x = 10, years = 30, real_interest_rate = -0.02)
calc_purchasing_power(x = 10, years = 30, real_interest_rate = 0.02)

Run the code above in your browser using DataLab