Learn R Programming

R4GoodPersonalFinances (version 1.2.0)

calc_gompertz_joint_parameters: Calculating the Gompertz model parameters for joint survival

Description

Calculating the Gompertz model parameters for joint survival

Usage

calc_gompertz_joint_parameters(
  p1 = list(age = NULL, mode = NULL, dispersion = NULL),
  p2 = list(age = NULL, mode = NULL, dispersion = NULL),
  max_age = 120
)

Value

A list containing:

data

A data frame with survival rates for 'p1', 'p2', 'joint' survival, and the fitted Gompertz model

mode

The mode of the joint Gompertz distribution

dispersion

The dispersion parameter of the joint Gompertz distribution

Arguments

p1

A list with age, mode and dispersion parameters for the first person (p1).

p2

A list with age, mode and dispersion parameters for the second person (p2).

max_age

A numeric. The maximum age for the Gompertz model.

Examples

Run this code
calc_gompertz_joint_parameters(
  p1 = list(
    age        = 65,
    mode       = 88,
    dispersion = 10.65
  ),
  p2 = list(
    age        = 60,
    mode       = 91,
    dispersion = 8.88
  ),
  max_age = 110
)

Run the code above in your browser using DataLab